from setuptools import setup

setup(name='gaus_bi_probability',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['gaus_bi_probability'],
      author= 'Adnan Mostafa',
      author_email= 'adnanmostafaprofessional@gmail.com',
      zip_safe=False)
